# ifndef yyAnaOverlap
# define yyAnaOverlap

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* AnaOverlap_Exit) ARGS ((void));

extern void OverlapAnalysis ARGS ((tTree t));

extern void BeginAnaOverlap ARGS ((void));
extern void CloseAnaOverlap ARGS ((void));

# endif
